package view;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import util.Log;

public class Setting implements Serializable {
	private static final String SETTING = ".setting";
	/**
	 * 設定を読み込みます。
	 * 設定ファイルが存在しない場合は、新たに作成します。
	 * @return 設定
	 */
	public static Setting readSetting() {
		ObjectInputStream bo = null;
		Setting setting = null;
		File file = new File(SETTING);
		try {
			try {
				bo = new ObjectInputStream(new FileInputStream(file));
				setting = (Setting) bo.readObject();
			} finally {
				if (bo != null) {
					bo.close();
				}
			}
		} catch (Exception e) {
			if (file.exists()) {
				file.delete();
			}
			setting = null;
		}
		if (setting == null) {
			setting = new Setting();
		}
		return setting;
	}

	private boolean update;
	
	private Setting() {
		this.update = true;
		this.isManual = true;
	}
	
	public boolean isUpdate() {
		return this.update;
	}
	
	public void setUpdate(boolean flag) {
		this.update = flag;
		this.write();
	}

	/**
	 * 操作マニュアルの表示フラグ
	 */
	private boolean isManual;

	public void switchManual() {
		this.isManual = !this.isManual;
		this.write();
	}
	
	public boolean isManual() {
		return this.isManual;
	}
	public boolean write() {
		File file = new File(SETTING);
		try {
			ObjectOutputStream bo = null;
			try {
				bo = new ObjectOutputStream(new FileOutputStream(file));
				bo.writeObject(this);
			} finally {
				if (bo != null) {
					bo.close();
				}
			}
		} catch (IOException e) {
			if (file.exists()) {
				file.delete();
			}
			Log.err(this, e);
			return false;
		}
		return true;
	}
}
